# Generated by Django 4.2.4 on 2023-09-02 06:01
from django.contrib.postgres.operations import HStoreExtension
from django.db import migrations


class Migration(migrations.Migration):
    initial = True

    dependencies = [
    ]

    operations = [
        HStoreExtension()
    ]
